@@ -33,8 +33,8 @@
 
 #include <climits>
 
-#include <qlinkedlist.h>
-#include <qmenu.h>
+#include <QLinkedList>
+#include <QMenu>
 
 #include <KSharedConfig>
 #include <kconfiggroup.h>
@@ -79,22 +79,23 @@ kpCommandHistoryBase::kpCommandHistoryBase (bool doReadConfig,
     m_actionUndo = new KToolBarPopupAction(KDE::icon("edit-undo"), undoActionText (), this);
     ac->addAction (KStandardAction::name (KStandardAction::Undo), m_actionUndo);
     ac->setDefaultShortcuts (m_actionUndo, KStandardShortcut::shortcut (KStandardShortcut::Undo));
-    connect (m_actionUndo, SIGNAL(triggered(bool)), this, SLOT (undo()));
+    connect (m_actionUndo, &KToolBarPopupAction::triggered, this, &kpCommandHistoryBase::undo);
 
     m_actionRedo = new KToolBarPopupAction(KDE::icon("edit-redo"), redoActionText (), this);
     ac->addAction (KStandardAction::name (KStandardAction::Redo), m_actionRedo);
     ac->setDefaultShortcuts (m_actionRedo, KStandardShortcut::shortcut (KStandardShortcut::Redo));
-    connect (m_actionRedo, SIGNAL(triggered(bool)), this, SLOT (redo()));
+    connect (m_actionRedo, &KToolBarPopupAction::triggered, this, &kpCommandHistoryBase::redo );
 
 
     m_actionUndo->setEnabled (false);
     m_actionRedo->setEnabled (false);
 
 
-    connect (m_actionUndo->menu (), SIGNAL (triggered(QAction*)),
-             this, SLOT (undoUpToNumber(QAction*)));
-    connect (m_actionRedo->menu (), SIGNAL (triggered(QAction*)),
-             this, SLOT (redoUpToNumber(QAction*)));
+    connect (m_actionUndo->menu(), &QMenu::triggered,
+             this, &kpCommandHistoryBase::undoUpToNumber);
+
+    connect (m_actionRedo->menu(), &QMenu::triggered,
+             this, &kpCommandHistoryBase::redoUpToNumber);
 
 
     m_undoMinLimit = 10;
@@ -105,8 +106,9 @@ kpCommandHistoryBase::kpCommandHistoryBase (bool doReadConfig,
     m_documentRestoredPosition = 0;
 
 
-    if (doReadConfig)
+    if (doReadConfig) {
         readConfig ();
+    }
 }
 
 kpCommandHistoryBase::~kpCommandHistoryBase ()
@@ -142,20 +144,19 @@ void kpCommandHistoryBase::setUndoMinLimit (int limit)
 {
 #if DEBUG_KP_COMMAND_HISTORY
     qCDebug(kpLogCommands) << "kpCommandHistoryBase::setUndoMinLimit("
-               << limit << ")"
-               << endl;
+               << limit << ")";
 #endif
 
     if (limit < 1 || limit > 5000/*"ought to be enough for anybody"*/)
     {
         qCCritical(kpLogCommands) << "kpCommandHistoryBase::setUndoMinLimit("
-                   << limit << ")"
-                   << endl;
+                   << limit << ")";
         return;
     }
 
-    if (limit == m_undoMinLimit)
+    if (limit == m_undoMinLimit) {
         return;
+    }
 
     m_undoMinLimit = limit;
     trimCommandListsUpdateActions ();
@@ -173,20 +174,19 @@ void kpCommandHistoryBase::setUndoMaxLimit (int limit)
 {
 #if DEBUG_KP_COMMAND_HISTORY
     qCDebug(kpLogCommands) << "kpCommandHistoryBase::setUndoMaxLimit("
-               << limit << ")"
-               << endl;
+               << limit << ")";
 #endif
 
     if (limit < 1 || limit > 5000/*"ought to be enough for anybody"*/)
     {
         qCCritical(kpLogCommands) << "kpCommandHistoryBase::setUndoMaxLimit("
-                   << limit << ")"
-                   << endl;
+                   << limit << ")";
         return;
     }
 
-    if (limit == m_undoMaxLimit)
+    if (limit == m_undoMaxLimit) {
         return;
+    }
 
     m_undoMaxLimit = limit;
     trimCommandListsUpdateActions ();
@@ -204,21 +204,20 @@ void kpCommandHistoryBase::setUndoMaxLimitSizeLimit (kpCommandSize::SizeType siz
 {
 #if DEBUG_KP_COMMAND_HISTORY
     qCDebug(kpLogCommands) << "kpCommandHistoryBase::setUndoMaxLimitSizeLimit("
-               << sizeLimit << ")"
-               << endl;
+               << sizeLimit << ")";
 #endif
 
     if (sizeLimit < 0 ||
         sizeLimit > (500 * 1048576)/*"ought to be enough for anybody"*/)
     {
         qCCritical(kpLogCommands) << "kpCommandHistoryBase::setUndoMaxLimitSizeLimit("
-                   << sizeLimit << ")"
-                   << endl;
+                   << sizeLimit << ")";
         return;
     }
 
-    if (sizeLimit == m_undoMaxLimitSizeLimit)
+    if (sizeLimit == m_undoMaxLimitSizeLimit) {
         return;
+    }
 
     m_undoMaxLimitSizeLimit = sizeLimit;
     trimCommandListsUpdateActions ();
@@ -266,28 +265,28 @@ void kpCommandHistoryBase::addCommand (kpCommand *command, bool execute)
     qCDebug(kpLogCommands) << "kpCommandHistoryBase::addCommand("
                << command
                << ",execute=" << execute << ")"
-               << endl;
 #endif
 
-    if (execute)
+    if (execute) {
         command->execute ();
+    }
 
     m_undoCommandList.push_front (command);
     ::ClearPointerList (&m_redoCommandList);
 
 #if DEBUG_KP_COMMAND_HISTORY
-    qCDebug(kpLogCommands) << "\tdocumentRestoredPosition=" << m_documentRestoredPosition
-               << endl;
+    qCDebug(kpLogCommands) << "\tdocumentRestoredPosition=" << m_documentRestoredPosition;
 #endif
     if (m_documentRestoredPosition != INT_MAX)
     {
-        if (m_documentRestoredPosition > 0)
+        if (m_documentRestoredPosition > 0) {
             m_documentRestoredPosition = INT_MAX;
-        else
+        }
+        else {
             m_documentRestoredPosition--;
+        }
     #if DEBUG_KP_COMMAND_HISTORY
-        qCDebug(kpLogCommands) << "\t\tdocumentRestoredPosition=" << m_documentRestoredPosition
-                << endl;
+        qCDebug(kpLogCommands) << "\t\tdocumentRestoredPosition=" << m_documentRestoredPosition;
     #endif
     }
 
@@ -319,8 +318,9 @@ void kpCommandHistoryBase::undoInternal ()
 #endif
 
     kpCommand *undoCommand = nextUndoCommand ();
-    if (!undoCommand)
+    if (!undoCommand) {
         return;
+    }
 
     undoCommand->unexecute ();
 
@@ -328,10 +328,8 @@ void kpCommandHistoryBase::undoInternal ()
     m_undoCommandList.erase (m_undoCommandList.begin ());
     m_redoCommandList.push_front (undoCommand);
 
-
 #if DEBUG_KP_COMMAND_HISTORY
-    qCDebug(kpLogCommands) << "\tdocumentRestoredPosition=" << m_documentRestoredPosition
-               << endl;
+    qCDebug(kpLogCommands) << "\tdocumentRestoredPosition=" << m_documentRestoredPosition;
 #endif
     if (m_documentRestoredPosition != INT_MAX)
     {
@@ -339,8 +337,7 @@ void kpCommandHistoryBase::undoInternal ()
         if (m_documentRestoredPosition == 0)
             emit documentRestored ();
     #if DEBUG_KP_COMMAND_HISTORY
-        qCDebug(kpLogCommands) << "\t\tdocumentRestoredPosition=" << m_documentRestoredPosition
-                   << endl;
+        qCDebug(kpLogCommands) << "\t\tdocumentRestoredPosition=" << m_documentRestoredPosition;
     #endif
     }
 }
@@ -355,8 +352,9 @@ void kpCommandHistoryBase::redoInternal ()
 #endif
 
     kpCommand *redoCommand = nextRedoCommand ();
-    if (!redoCommand)
+    if (!redoCommand) {
         return;
+    }
 
     redoCommand->execute ();
 
@@ -364,19 +362,17 @@ void kpCommandHistoryBase::redoInternal ()
     m_redoCommandList.erase (m_redoCommandList.begin ());
     m_undoCommandList.push_front (redoCommand);
 
-
 #if DEBUG_KP_COMMAND_HISTORY
-    qCDebug(kpLogCommands) << "\tdocumentRestoredPosition=" << m_documentRestoredPosition
-               << endl;
+    qCDebug(kpLogCommands) << "\tdocumentRestoredPosition=" << m_documentRestoredPosition;
 #endif
     if (m_documentRestoredPosition != INT_MAX)
     {
         m_documentRestoredPosition--;
-        if (m_documentRestoredPosition == 0)
+        if (m_documentRestoredPosition == 0) {
             emit documentRestored ();
+        }
     #if DEBUG_KP_COMMAND_HISTORY
-        qCDebug(kpLogCommands) << "\t\tdocumentRestoredPosition=" << m_documentRestoredPosition
-                   << endl;
+        qCDebug(kpLogCommands) << "\t\tdocumentRestoredPosition=" << m_documentRestoredPosition;
     #endif
     }
 }
@@ -449,10 +445,7 @@ QString kpCommandHistoryBase::undoActionText () const
 {
     kpCommand *undoCommand = nextUndoCommand ();
 
-    if (undoCommand)
-        return i18n ("&Undo: %1", undoCommand->name ());
-    else
-        return i18n ("&Undo");
+    return (undoCommand) ? i18n ("&Undo: %1", undoCommand->name ()) : i18n ("&Undo");
 }
 
 // protected
@@ -460,10 +453,7 @@ QString kpCommandHistoryBase::redoActionText () const
 {
     kpCommand *redoCommand = nextRedoCommand ();
 
-    if (redoCommand)
-        return i18n ("&Redo: %1", redoCommand->name ());
-    else
-        return i18n ("&Redo");
+    return (redoCommand) ? i18n ("&Redo: %1", redoCommand->name ()) : i18n ("&Redo");
 }
 
 
@@ -472,10 +462,7 @@ QString kpCommandHistoryBase::undoActionToolTip () const
 {
     kpCommand *undoCommand = nextUndoCommand ();
 
-    if (undoCommand)
-        return i18n ("Undo: %1", undoCommand->name ());
-    else
-        return i18n ("Undo");
+    return (undoCommand) ? i18n ("Undo: %1", undoCommand->name ()) : i18n ("Undo");
 }
 
 // protected
@@ -483,10 +470,7 @@ QString kpCommandHistoryBase::redoActionToolTip () const
 {
     kpCommand *redoCommand = nextRedoCommand ();
 
-    if (redoCommand)
-        return i18n ("Redo: %1", redoCommand->name ());
-    else
-        return i18n ("Redo");
+    return (redoCommand) ? i18n ("Redo: %1", redoCommand->name ()) : i18n ("Redo");
 }
 
 
@@ -511,8 +495,7 @@ void kpCommandHistoryBase::trimCommandList (QLinkedList <kpCommand *> *commandLi
 
     if (!commandList)
     {
-        qCCritical(kpLogCommands) << "kpCommandHistoryBase::trimCommandList() passed 0 commandList"
-                   << endl;
+        qCCritical(kpLogCommands) << "kpCommandHistoryBase::trimCommandList() passed 0 commandList";
         return;
     }
 
@@ -521,10 +504,9 @@ void kpCommandHistoryBase::trimCommandList (QLinkedList <kpCommand *> *commandLi
     qCDebug(kpLogCommands) << "\tsize=" << commandList->size ()
                << "    undoMinLimit=" << m_undoMinLimit
                << " undoMaxLimit=" << m_undoMaxLimit
-               << " undoMaxLimitSizeLimit=" << m_undoMaxLimitSizeLimit
-               << endl;
+               << " undoMaxLimitSizeLimit=" << m_undoMaxLimitSizeLimit;
 #endif
-    if ((int) commandList->size () <= m_undoMinLimit)
+    if (static_cast<int> (commandList->size ()) <= m_undoMinLimit)
     {
     #if DEBUG_KP_COMMAND_HISTORY
         qCDebug(kpLogCommands) << "\t\tsize under undoMinLimit - done";
@@ -555,8 +537,7 @@ void kpCommandHistoryBase::trimCommandList (QLinkedList <kpCommand *> *commandLi
         qCDebug(kpLogCommands) << "\t\t" << upto << ":"
                    << " name='" << (*it)->name ()
                    << "' size=" << (*it)->size ()
-                   << "    sizeSoFar=" << sizeSoFar
-                   << endl;
+                   << "    sizeSoFar=" << sizeSoFar;
     #endif
 
         if (upto >= m_undoMinLimit)
@@ -573,8 +554,9 @@ void kpCommandHistoryBase::trimCommandList (QLinkedList <kpCommand *> *commandLi
             }
         }
 
-        if (advanceIt)
+        if (advanceIt) {
             it++;
+        }
         upto++;
     }
 
@@ -595,17 +577,15 @@ void kpCommandHistoryBase::trimCommandLists ()
 
 #if DEBUG_KP_COMMAND_HISTORY
     qCDebug(kpLogCommands) << "\tdocumentRestoredPosition=" << m_documentRestoredPosition
-               << endl;
 #endif
     if (m_documentRestoredPosition != INT_MAX)
     {
     #if DEBUG_KP_COMMAND_HISTORY
         qCDebug(kpLogCommands) << "\t\tundoCmdList.size=" << m_undoCommandList.size ()
-                   << " redoCmdList.size=" << m_redoCommandList.size ()
-                   << endl;
+                   << " redoCmdList.size=" << m_redoCommandList.size ();
     #endif
-        if (m_documentRestoredPosition > (int) m_redoCommandList.size () ||
-            -m_documentRestoredPosition > (int) m_undoCommandList.size ())
+        if (m_documentRestoredPosition > static_cast<int> (m_redoCommandList.size ()) ||
+            -m_documentRestoredPosition > static_cast<int> (m_undoCommandList.size ()))
         {
         #if DEBUG_KP_COMMAND_HISTORY
             qCDebug(kpLogCommands) << "\t\t\tinvalidate documentRestoredPosition";
@@ -620,8 +600,9 @@ static void populatePopupMenu (QMenu *popupMenu,
                                const QString &undoOrRedo,
                                const QLinkedList <kpCommand *> &commandList)
 {
-    if (!popupMenu)
+    if (!popupMenu) {
         return;
+    }
 
     popupMenu->clear ();
 
@@ -632,7 +613,8 @@ static void populatePopupMenu (QMenu *popupMenu,
         QAction *action = new QAction(i18n ("%1: %2", undoOrRedo, (*it)->name ()), popupMenu);
         action->setData(i);
         popupMenu->addAction (action);
-        i++, it++;
+        i++;
+        it++;
     }
 
     if (it != commandList.end ())
@@ -652,7 +634,7 @@ void kpCommandHistoryBase::updateActions ()
     qCDebug(kpLogCommands) << "kpCommandHistoryBase::updateActions()";
 #endif
 
-    m_actionUndo->setEnabled ((bool) nextUndoCommand ());
+    m_actionUndo->setEnabled (static_cast<bool> (nextUndoCommand ()));
     // Don't want to keep changing toolbar text.
     // TODO: As a bad side-effect, the menu doesn't have "Undo: <action>"
     //       anymore.  In any case, the KDE4 KToolBarPopupAction
@@ -670,10 +652,10 @@ void kpCommandHistoryBase::updateActions ()
                        m_undoCommandList);
 #if DEBUG_KP_COMMAND_HISTORY
     qCDebug(kpLogCommands) << "\tpopuplatePopupMenu undo=" << timer.elapsed ()
-               << "ms" << endl;;
+               << "ms";
 #endif
 
-    m_actionRedo->setEnabled ((bool) nextRedoCommand ());
+    m_actionRedo->setEnabled (static_cast<bool> (nextRedoCommand ()));
     // Don't want to keep changing toolbar text.
     // TODO: As a bad side-effect, the menu doesn't have "Undo: <action>"
     //       anymore.  In any case, the KDE4 KToolBarPopupAction
@@ -691,7 +673,7 @@ void kpCommandHistoryBase::updateActions ()
                        m_redoCommandList);
 #if DEBUG_KP_COMMAND_HISTORY
     qCDebug(kpLogCommands) << "\tpopuplatePopupMenu redo=" << timer.elapsed ()
-               << "ms" << endl;
+               << "ms";
 #endif
 }
 
@@ -699,8 +681,9 @@ void kpCommandHistoryBase::updateActions ()
 // public
 kpCommand *kpCommandHistoryBase::nextUndoCommand () const
 {
-    if (m_undoCommandList.isEmpty ())
+    if (m_undoCommandList.isEmpty ()) {
         return nullptr;
+    }
 
     return m_undoCommandList.first ();
 }
@@ -708,8 +691,9 @@ kpCommand *kpCommandHistoryBase::nextUndoCommand () const
 // public
 kpCommand *kpCommandHistoryBase::nextRedoCommand () const
 {
-    if (m_redoCommandList.isEmpty ())
+    if (m_redoCommandList.isEmpty ()) {
         return nullptr;
+    }
 
     return m_redoCommandList.first ();
 }
@@ -719,20 +703,16 @@ kpCommand *kpCommandHistoryBase::nextRedoCommand () const
 void kpCommandHistoryBase::setNextUndoCommand (kpCommand *command)
 {
 #if DEBUG_KP_COMMAND_HISTORY
-    qCDebug(kpLogCommands) << "kpCommandHistoryBase::setNextUndoCommand("
-               << command
-               << ")"
-               << endl;
+    qCDebug(kpLogCommands) << "kpCommandHistoryBase::setNextUndoCommand("<< command << ")";
 #endif
 
-    if (m_undoCommandList.isEmpty ())
+    if (m_undoCommandList.isEmpty ()) {
         return;
-
+    }
 
     delete *m_undoCommandList.begin ();
     *m_undoCommandList.begin () = command;
 
-
     trimCommandListsUpdateActions ();
 }
 
