@@ -37,7 +37,7 @@
 SaneDialog::SaneDialog(QWidget *parent)
     : KPageDialog(parent)
 {
-    setFaceType((KPageDialog::FaceType)Plain);
+    setFaceType(static_cast<KPageDialog::FaceType> (Plain));
     setWindowTitle(i18nc("@title:window", "Acquire Image"));
 
     buttonBox()->setStandardButtons(QDialogButtonBox::Close);
@@ -47,8 +47,8 @@ SaneDialog::SaneDialog(QWidget *parent)
     m_ksanew = new KSaneIface::KSaneWidget(this);
     addPage(m_ksanew, QString());
 
-    connect(m_ksanew, SIGNAL(imageReady(QByteArray&,int,int,int,int)),
-            this, SLOT(imageReady(QByteArray&,int,int,int,int)));
+    connect (m_ksanew, &KSaneIface::KSaneWidget::imageReady,
+             this, &SaneDialog::imageReady);
 
     m_openDev = QString();
 }
@@ -63,14 +63,14 @@ bool SaneDialog::setup()
         return true;
     }
     // need to select a scanner
-    m_openDev = m_ksanew->selectDevice(0);
+    m_openDev = m_ksanew->selectDevice(nullptr);
     if (m_openDev.isEmpty()) {
        // either no scanner was found or then cancel was pressed.
         return false;
     }
-    if (m_ksanew->openDevice(m_openDev) == false) {
+    if (!m_ksanew->openDevice(m_openDev)) {
         // could not open the scanner
-        KMessageBox::sorry(0, i18n("Opening the selected scanner failed."));
+        KMessageBox::sorry(nullptr, i18n("Opening the selected scanner failed."));
         m_openDev = QString();
         return false;
     }
@@ -82,8 +82,9 @@ bool SaneDialog::setup()
     if (configPtr->hasGroup(groupName)) {
         KConfigGroup group(configPtr, groupName);
         QStringList keys = group.keyList();
-        for (int i = 0; i < keys.count(); i++)
+        for (int i = 0; i < keys.count(); i++) {
             m_ksanew->setOptVal(keys[i], group.readEntry(keys[i]));
+        }
     }
 
    return true;
@@ -100,15 +101,16 @@ SaneDialog::~SaneDialog()
         QMap<QString, QString> opts;
         m_ksanew->getOptVals(opts);
         QMap<QString, QString>::const_iterator i = opts.constBegin();
-        for (; i != opts.constEnd(); ++i)
+        for (; i != opts.constEnd(); ++i) {
             group.writeEntry(i.key(), i.value(), KConfigGroup::Persistent);
+        }
     }
 }
 
 void SaneDialog::imageReady(QByteArray &data, int w, int h, int bpl, int f)
 {
     /* copy the image data into img */
-    QImage img = m_ksanew->toQImage(data, w, h, bpl, (KSaneIface::KSaneWidget::ImageFormat)f);
+    QImage img = m_ksanew->toQImage(data, w, h, bpl, static_cast<KSaneIface::KSaneWidget::ImageFormat> (f));
     emit finalImage(img, nextId());
 }
 
