@@ -51,8 +51,9 @@ QRect kpView::selectionViewRect () const
 // public
 QPoint kpView::mouseViewPointRelativeToSelection (const QPoint &viewPoint) const
 {
-    if (!selection ())
+    if (!selection ()) {
         return KP_INVALID_POINT;
+    }
 
     return mouseViewPoint (viewPoint) - transformDocToView (selection ()->topLeft ());
 }
@@ -61,8 +62,9 @@ QPoint kpView::mouseViewPointRelativeToSelection (const QPoint &viewPoint) const
 bool kpView::mouseOnSelection (const QPoint &viewPoint) const
 {
     const QRect selViewRect = selectionViewRect ();
-    if (!selViewRect.isValid ())
+    if (!selViewRect.isValid ()) {
         return false;
+    }
 
     return selViewRect.contains (mouseViewPoint (viewPoint));
 }
@@ -71,8 +73,9 @@ bool kpView::mouseOnSelection (const QPoint &viewPoint) const
 // public
 int kpView::textSelectionMoveBorderAtomicSize () const
 {
-    if (!textSelection ())
+    if (!textSelection ()) {
         return 0;
+    }
 
     return qMax (4, zoomLevelX () / 100);
 }
@@ -80,14 +83,17 @@ int kpView::textSelectionMoveBorderAtomicSize () const
 // public
 bool kpView::mouseOnSelectionToMove (const QPoint &viewPoint) const
 {
-    if (!mouseOnSelection (viewPoint))
+    if (!mouseOnSelection (viewPoint)) {
         return false;
+    }
 
-    if (!textSelection ())
+    if (!textSelection ()) {
         return true;
+    }
 
-    if (mouseOnSelectionResizeHandle (viewPoint))
+    if (mouseOnSelectionResizeHandle (viewPoint)) {
         return false;
+    }
 
 
     const QPoint viewPointRelSel = mouseViewPointRelativeToSelection (viewPoint);
@@ -115,8 +121,9 @@ bool kpView::mouseOnSelectionToMove (const QPoint &viewPoint) const
 // protected
 bool kpView::selectionLargeEnoughToHaveResizeHandlesIfAtomicSize (int atomicSize) const
 {
-    if (!selection ())
+    if (!selection ()) {
         return false;
+    }
 
     const QRect selViewRect = selectionViewRect ();
 
@@ -153,8 +160,9 @@ bool kpView::selectionLargeEnoughToHaveResizeHandles () const
 QRegion kpView::selectionResizeHandlesViewRegion (bool forRenderer) const
 {
     const int atomicLength = selectionResizeHandleAtomicSize ();
-    if (atomicLength <= 0)
+    if (atomicLength <= 0) {
         return QRegion ();
+    }
 
 
     // HACK: At low zoom (e.g. 100%), resize handles will probably be too
@@ -173,20 +181,24 @@ QRegion kpView::selectionResizeHandlesViewRegion (bool forRenderer) const
     {
         if (zoomLevelX () <= 150)
         {
-            if (normalAtomicLength > 1)
+            if (normalAtomicLength > 1) {
                 normalAtomicLength--;
+            }
 
-            if (vertEdgeAtomicLength > 1)
+            if (vertEdgeAtomicLength > 1) {
                 vertEdgeAtomicLength--;
+            }
         }
 
         // 1 line of text?
         if (textSelection () && textSelection ()->textLines ().size () == 1)
         {
-            if (zoomLevelX () <= 150)
+            if (zoomLevelX () <= 150) {
                 vertEdgeAtomicLength = qMin (vertEdgeAtomicLength, qMax (2, zoomLevelX () / 100));
-            else if (zoomLevelX () <= 250)
+            }
+            else if (zoomLevelX () <= 250) {
                 vertEdgeAtomicLength = qMin (vertEdgeAtomicLength, qMax (3, zoomLevelX () / 100));
+            }
         }
     }
 
@@ -238,14 +250,14 @@ QRegion kpView::selectionResizeHandlesViewRegion (bool forRenderer) const
 int kpView::mouseOnSelectionResizeHandle (const QPoint &viewPoint) const
 {
 #if DEBUG_KP_VIEW
-    kDebug () << "kpView::mouseOnSelectionResizeHandle(viewPoint="
+    qCDebug(kpLogViews) << "kpView::mouseOnSelectionResizeHandle(viewPoint="
                << viewPoint << ")" << endl;
 #endif
 
     if (!mouseOnSelection (viewPoint))
     {
     #if DEBUG_KP_VIEW
-        kDebug () << "\tmouse not on sel";
+        qCDebug(kpLogViews) << "\tmouse not on sel";
     #endif
         return 0;
     }
@@ -253,19 +265,19 @@ int kpView::mouseOnSelectionResizeHandle (const QPoint &viewPoint) const
 
     const QRect selViewRect = selectionViewRect ();
 #if DEBUG_KP_VIEW
-    kDebug () << "\tselViewRect=" << selViewRect;
+    qCDebug(kpLogViews) << "\tselViewRect=" << selViewRect;
 #endif
 
 
     const int atomicLength = selectionResizeHandleAtomicSize ();
 #if DEBUG_KP_VIEW
-    kDebug () << "\tatomicLength=" << atomicLength;
+    qCDebug(kpLogViews) << "\tatomicLength=" << atomicLength;
 #endif
 
     if (atomicLength <= 0)
     {
     #if DEBUG_KP_VIEW
-        kDebug () << "\tsel not large enough to have resize handles";
+        qCDebug(kpLogViews) << "\tsel not large enough to have resize handles";
     #endif
         // Want to make it possible to move a small selection
         return 0;
@@ -274,7 +286,7 @@ int kpView::mouseOnSelectionResizeHandle (const QPoint &viewPoint) const
 
     const QPoint viewPointRelSel = mouseViewPointRelativeToSelection (viewPoint);
 #if DEBUG_KP_VIEW
-    kDebug () << "\tviewPointRelSel=" << viewPointRelSel;
+    qCDebug(kpLogViews) << "\tviewPointRelSel=" << viewPointRelSel;
 #endif
 
 
@@ -287,40 +299,47 @@ int kpView::mouseOnSelectionResizeHandle (const QPoint &viewPoint) const
     {
         return kpView::Bottom | kpView::Right;
     }
-    else if (LOCAL_POINT_IN_BOX_AT (selViewRect.width () - atomicLength, 0))
+
+    if (LOCAL_POINT_IN_BOX_AT (selViewRect.width () - atomicLength, 0))
     {
         return kpView::Top | kpView::Right;
     }
-    else if (LOCAL_POINT_IN_BOX_AT (0, selViewRect.height () - atomicLength))
+
+    if (LOCAL_POINT_IN_BOX_AT (0, selViewRect.height () - atomicLength))
     {
         return kpView::Bottom | kpView::Left;
     }
-    else if (LOCAL_POINT_IN_BOX_AT (0, 0))
+
+    if (LOCAL_POINT_IN_BOX_AT (0, 0))
     {
         return kpView::Top | kpView::Left;
     }
-    else if (LOCAL_POINT_IN_BOX_AT (selViewRect.width () - atomicLength,
+
+    if (LOCAL_POINT_IN_BOX_AT (selViewRect.width () - atomicLength,
                                     (selViewRect.height () - atomicLength) / 2))
     {
         return kpView::Right;
     }
-    else if (LOCAL_POINT_IN_BOX_AT ((selViewRect.width () - atomicLength) / 2,
+
+    if (LOCAL_POINT_IN_BOX_AT ((selViewRect.width () - atomicLength) / 2,
                                     selViewRect.height () - atomicLength))
     {
         return kpView::Bottom;
     }
-    else if (LOCAL_POINT_IN_BOX_AT ((selViewRect.width () - atomicLength) / 2, 0))
+
+    if (LOCAL_POINT_IN_BOX_AT ((selViewRect.width () - atomicLength) / 2, 0))
     {
         return kpView::Top;
     }
-    else if (LOCAL_POINT_IN_BOX_AT (0, (selViewRect.height () - atomicLength) / 2))
+
+    if (LOCAL_POINT_IN_BOX_AT (0, (selViewRect.height () - atomicLength) / 2))
     {
         return kpView::Left;
     }
     else
     {
     #if DEBUG_KP_VIEW
-        kDebug () << "\tnot on sel resize handle";
+        qCDebug(kpLogViews) << "\tnot on sel resize handle";
     #endif
         return 0;
     }
@@ -331,14 +350,14 @@ int kpView::mouseOnSelectionResizeHandle (const QPoint &viewPoint) const
 bool kpView::mouseOnSelectionToSelectText (const QPoint &viewPoint) const
 {
 #if DEBUG_KP_VIEW
-    kDebug () << "kpView::mouseOnSelectionToSelectText(viewPoint="
+    qCDebug(kpLogViews) << "kpView::mouseOnSelectionToSelectText(viewPoint="
                << viewPoint << ")" << endl;
 #endif
 
     if (!mouseOnSelection (viewPoint))
     {
     #if DEBUG_KP_VIEW
-        kDebug () << "\tmouse non on sel";
+        qCDebug(kpLogViews) << "\tmouse non on sel";
     #endif
         return false;
     }
@@ -346,13 +365,13 @@ bool kpView::mouseOnSelectionToSelectText (const QPoint &viewPoint) const
     if (!textSelection ())
     {
     #if DEBUG_KP_VIEW
-        kDebug () << "\tsel not text";
+        qCDebug(kpLogViews) << "\tsel not text";
     #endif
         return false;
     }
 
 #if DEBUG_KP_VIEW
-    kDebug () << "\tmouse on sel: to move=" << mouseOnSelectionToMove ()
+    qCDebug(kpLogViews) << "\tmouse on sel: to move=" << mouseOnSelectionToMove ()
                << " to resize=" << mouseOnSelectionResizeHandle ()
                << endl;
 #endif
