@@ -90,17 +90,20 @@ void kpDualColorButton::setColor (int which, const kpColor &color)
 {
     Q_ASSERT (which == 0 || which == 1);
 
-    if (m_color [which] == color)
+    if (m_color [which] == color) {
         return;
+    }
 
     m_oldColor [which] = m_color [which];
     m_color [which] = color;
     update ();
 
-    if (which == 0)
+    if (which == 0) {
         emit foregroundColorChanged (color);
-    else
+    }
+    else {
         emit backgroundColorChanged (color);
+    }
 }
 
 //---------------------------------------------------------------------
@@ -140,7 +143,7 @@ kpColor kpDualColorButton::oldBackgroundColor () const
 // public virtual [base QWidget]
 QSize kpDualColorButton::sizeHint () const
 {
-    return QSize (52, 52);
+    return  {52, 52};
 }
 
 //---------------------------------------------------------------------
@@ -151,10 +154,8 @@ QRect kpDualColorButton::swapPixmapRect () const
 {
     QPixmap swapPixmap = UserIcon ("colorbutton_swap_16x16");
 
-    return QRect (contentsRect ().width () - swapPixmap.width (),
-                  0,
-                  swapPixmap.width (),
-                  swapPixmap.height ());
+    return  {contentsRect ().width () - swapPixmap.width (), 0,
+                swapPixmap.width (), swapPixmap.height ()};
 }
 
 //---------------------------------------------------------------------
@@ -163,10 +164,8 @@ QRect kpDualColorButton::swapPixmapRect () const
 QRect kpDualColorButton::foregroundBackgroundRect () const
 {
     QRect cr (contentsRect ());
-    return QRect (cr.width () / 8,
-                  cr.height () / 8,
-                  cr.width () * 6 / 8,
-                  cr.height () * 6 / 8);
+    return  {cr.width () / 8, cr.height () / 8,
+                cr.width () * 6 / 8, cr.height () * 6 / 8};
 }
 
 //---------------------------------------------------------------------
@@ -175,10 +174,8 @@ QRect kpDualColorButton::foregroundBackgroundRect () const
 QRect kpDualColorButton::foregroundRect () const
 {
     QRect fbr (foregroundBackgroundRect ());
-    return QRect (fbr.x (),
-                  fbr.y (),
-                  fbr.width () * 3 / 4,
-                  fbr.height () * 3 / 4);
+    return  {fbr.x (), fbr.y (),
+                fbr.width () * 3 / 4, fbr.height () * 3 / 4};
 }
 
 //---------------------------------------------------------------------
@@ -187,10 +184,8 @@ QRect kpDualColorButton::foregroundRect () const
 QRect kpDualColorButton::backgroundRect () const
 {
     QRect fbr (foregroundBackgroundRect ());
-    return QRect (fbr.x () + fbr.width () / 4,
-                  fbr.y () + fbr.height () / 4,
-                  fbr.width () * 3 / 4,
-                  fbr.height () * 3 / 4);
+    return  {fbr.x () + fbr.width () / 4, fbr.y () + fbr.height () / 4,
+                fbr.width () * 3 / 4, fbr.height () * 3 / 4};
 }
 
 //---------------------------------------------------------------------
@@ -201,8 +196,7 @@ void kpDualColorButton::dragEnterEvent (QDragEnterEvent *e)
 {
 #if DEBUG_KP_DUAL_COLOR_BUTTON
     qCDebug(kpLogWidgets) << "kpDualColorButton::dragEnterEvent() canDecode="
-              << KColorMimeData::canDecode (e->mimeData ())
-              << endl;
+              << KColorMimeData::canDecode (e->mimeData ());
 #endif
     e->accept ();
 }
@@ -214,8 +208,7 @@ void kpDualColorButton::dragMoveEvent (QDragMoveEvent *e)
 {
 #if DEBUG_KP_DUAL_COLOR_BUTTON
     qCDebug(kpLogWidgets) << "kpDualColorButton::dragMoveEvent() canDecode="
-              << KColorMimeData::canDecode (e->mimeData ())
-              << endl;
+              << KColorMimeData::canDecode (e->mimeData ());
 #endif
     e->setAccepted (
         (foregroundRect ().contains (e->pos ()) ||
@@ -232,15 +225,17 @@ void kpDualColorButton::dropEvent (QDropEvent *e)
 #if DEBUG_KP_DUAL_COLOR_BUTTON
     qCDebug(kpLogWidgets) << "kpDualColorButton::dropEvent() col="
               << (int *) col.rgba()
-              << " (with alpha=" << (int *) col.rgba () << ")" << endl;
+              << " (with alpha=" << (int *) col.rgba () << ")";
 #endif
 
     if (col.isValid ())
     {
-        if (foregroundRect ().contains (e->pos ()))
+        if (foregroundRect ().contains (e->pos ())) {
             setForegroundColor (kpColor (col.rgba()));
-        else if (backgroundRect ().contains (e->pos ()))
+        }
+        else if (backgroundRect ().contains (e->pos ())) {
             setBackgroundColor (kpColor (col.rgba()));
+        }
     }
 }
 
@@ -256,8 +251,9 @@ void kpDualColorButton::mousePressEvent (QMouseEvent *e)
 
     m_dragStartPoint = KP_INVALID_POINT;
 
-    if (e->button () == Qt::LeftButton)
+    if (e->button () == Qt::LeftButton) {
         m_dragStartPoint = e->pos ();
+    }
 }
 
 //---------------------------------------------------------------------
@@ -270,8 +266,9 @@ void kpDualColorButton::mouseMoveEvent (QMouseEvent *e)
               << " dragStartPoint=" << m_dragStartPoint << endl;
 #endif
 
-    if (m_dragStartPoint == KP_INVALID_POINT)
+    if (m_dragStartPoint == KP_INVALID_POINT) {
         return;
+    }
 
     if (!(e->buttons () & Qt::LeftButton))
     {
@@ -291,13 +288,11 @@ void kpDualColorButton::mouseMoveEvent (QMouseEvent *e)
 
         kpColor color;
 
-        if (foregroundRect ().contains (m_dragStartPoint))
+        if (foregroundRect ().contains (m_dragStartPoint)) {
             color = foregroundColor ();
-        else if (backgroundRect ().contains (m_dragStartPoint))
+        }
+        else if (backgroundRect ().contains (m_dragStartPoint)) {
             color = backgroundColor ();
-        else
-        {
-            // "color" is left as invalid.
         }
 
     #if DEBUG_KP_DUAL_COLOR_BUTTON
@@ -308,8 +303,9 @@ void kpDualColorButton::mouseMoveEvent (QMouseEvent *e)
 
         if (color.isValid ())
         {
-            if (!color.isTransparent ())
+            if (!color.isTransparent ()) {
                 KColorMimeData::createDrag (color.toQColor (), this)->exec ();
+            }
         }
 
         m_dragStartPoint = KP_INVALID_POINT;
@@ -351,18 +347,21 @@ void kpDualColorButton::mouseDoubleClickEvent (QMouseEvent *e)
 {
     int whichColor = -1;
 
-    if (foregroundRect ().contains (e->pos ()))
+    if (foregroundRect ().contains (e->pos ())) {
         whichColor = 0;
-    else if (backgroundRect ().contains (e->pos ()))
+    }
+    else if (backgroundRect ().contains (e->pos ())) {
         whichColor = 1;
+    }
 
     if (whichColor == 0 || whichColor == 1)
     {
         QColorDialog dialog(this);
         dialog.setCurrentColor(color(whichColor).toQColor());
         dialog.setOptions(QColorDialog::ShowAlphaChannel);
-        if ( dialog.exec() == QDialog::Accepted )
+        if ( dialog.exec() == QDialog::Accepted ) {
           setColor(whichColor, kpColor(dialog.currentColor().rgba()));
+        }
     }
 }
 
@@ -425,18 +424,22 @@ void kpDualColorButton::paintEvent (QPaintEvent *e)
         qCDebug(kpLogWidgets) << "\tbackgroundColor=" << (int *) m_color [1].toQRgb ()
                    << endl;
     #endif
-        if (m_color [1].isTransparent ())  // only if fully transparent
+        if (m_color [1].isTransparent ()) { // only if fully transparent
             painter.drawPixmap (bgRectInside, UserIcon ("color_transparent_26x26"));
-        else
+        }
+        else {
             painter.fillRect (bgRectInside, m_color [1].toQColor ());
+        }
     }
-    else
+    else {
         painter.fillRect (bgRectInside, palette().color (QPalette::Button));
+    }
     qDrawShadePanel (&painter, bgRect, palette(),
                      false/*not sunken*/, 2/*lineWidth*/,
                      nullptr/*never fill*/);
 
 
+
     // Draw foreground colour patch.
     // Must be drawn after background patch since we're on top.
     QRect fgRect = foregroundRect ();
@@ -448,13 +451,16 @@ void kpDualColorButton::paintEvent (QPaintEvent *e)
         qCDebug(kpLogWidgets) << "\tforegroundColor=" << (int *) m_color [0].toQRgb ()
                    << endl;
     #endif
-        if (m_color [0].isTransparent ())  // only if fully transparent
+        if (m_color [0].isTransparent ()) { // only if fully transparent
             painter.drawPixmap (fgRectInside, UserIcon ("color_transparent_26x26"));
-        else
+        }
+        else {
             painter.fillRect (fgRectInside, m_color [0].toQColor ());
+        }
     }
-    else
+    else {
         painter.fillRect (fgRectInside, palette ().color (QPalette::Button));
+    }
 
     qDrawShadePanel (&painter, fgRect, palette (),
                      false/*not sunken*/, 2/*lineWidth*/,
